/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.activities;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Toast;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.cloud.sdk.list.item.Share;
import com.thingspace.cloud.sdk.request.ShareResource;
import com.thingspace.media.R;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewListAdapter;
import com.thingspace.media.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.media.dialog.CreateShareDialog;
import com.thingspace.media.listeners.RecyclerViewClickListener;
import com.thingspace.media.tasks.share.CreateShareTask;
import com.thingspace.media.tasks.share.DeleteSharesTask;
import com.thingspace.media.tasks.share.GetSharesTask;
import com.thingspace.media.tasks.HubbleMediaTask;

import java.util.ArrayList;

/**
 * SharesListActivity is called when Shares is selected from the options menu which displays the list of all the items shared to the user.
 */
public class SharesListActivity extends BaseActivity implements OnBindViewInterface, RecyclerViewClickListener {

    private static ItemList<Share> itemListShares;
    private Toolbar toolbar;
    private RecyclerView recyclerView;
    protected FloatingActionButton floatingActionButton;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.resource_recycler_view);

        toolbar = (Toolbar) findViewById(R.id.toolbar);
        toolbar.setVisibility(View.VISIBLE);
        setSupportActionBar(toolbar);
        getSupportActionBar().setTitle(getString(R.string.action_shares));
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        floatingActionButton = (FloatingActionButton) findViewById(R.id.fab);
        floatingActionButton.setVisibility(View.VISIBLE);
        floatingActionButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                CreateShareDialog createShareDialog = new CreateShareDialog();
                createShareDialog.show(getSupportFragmentManager(), "create_share");
            }
        });

        getShares();
    }

    private void getShares() {
        showProgressDialog(getString(R.string.loading));
        GetSharesTask task = new GetSharesTask(this, this, cloudAPI);
        task.execute();
    }

    @Override
    public void onResponse(int taskCode, int responseCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_GET_SHARES) {
            dismissProgressDialog();
            if (response == null || !(response instanceof ItemList)) {
                return;
            }

            itemListShares = (ItemList) response;
            recyclerView = (RecyclerView) findViewById(R.id.recyclerView);
            recyclerView.setLayoutManager(new LinearLayoutManager(this));
            recyclerView.setAdapter(new RecyclerViewListAdapter(R.layout.list_item_contacts, itemListShares, this, this));
            getSupportActionBar().setTitle(getString(R.string.title_activity_shares, itemListShares.getCount()));
            return;
        } else if (taskCode == HubbleMediaTask.TASK_DELETE_SHARE) {
            dismissProgressDialog();
            if (response != null && response instanceof Boolean) {
                Toast.makeText(this, (boolean) response ? "Share Deleted" : "Share could not be deleted", Toast.LENGTH_SHORT).show();
                if ((boolean) response) {
                    getShares();
                }
            }
        } else if (taskCode == HubbleMediaTask.TASK_CREATE_SHARE) {
            dismissProgressDialog();
            if (response instanceof Share) {
                Toast.makeText(this, "Share created", Toast.LENGTH_SHORT).show();
                Share share = (Share) response;
                Log.d("Create Share", "Share Name: " + share.getName() + " uid: " + share.getUid() + " Creation Date: " + share.getCreationDate());
                getShares();
            } else {
                Toast.makeText(this, "Share could not be created", Toast.LENGTH_SHORT).show();
            }
        }

        super.onResponse(taskCode, responseCode, response);
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
        Share share = (Share) item;
        ((RecyclerViewListHolder) holder).textView.setText(share.getName() + " (" + share.getTotalResourceCount() + ")");
        ((RecyclerViewListHolder) holder).textView2.setVisibility(View.GONE);
    }

    /**
     * When each contact is selected, ContactActivity is called which displays all the details of the contact
     * @param view     image view that was clicked
     * @param position position in the recycler view
     */
    @Override
    public void onListItemClicked(View view, int position) {

    }

    @Override
    public void onListItemLongClicked(View view, int position) {
        final Share share = itemListShares.getItem(position);
        AlertDialog.Builder fileOperationDialog = new AlertDialog.Builder(this);
        final ArrayAdapter<String> arrayAdapter = new ArrayAdapter<>(this, R.layout.list_item);

        arrayAdapter.add(getString(R.string.action_delete));

        fileOperationDialog.setAdapter(arrayAdapter, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                switch (which) {
                    case 0:
                        showProgressDialog(getString(R.string.loading));
                        DeleteSharesTask task = new DeleteSharesTask(SharesListActivity.this, SharesListActivity.this, cloudAPI, share.getUid());
                        task.execute();
                }
            }
        });

        fileOperationDialog.setTitle(getString(R.string.file_actions));
        fileOperationDialog.create();
        fileOperationDialog.show();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (data == null) {
            return;
        }

        String shareName = data.getStringExtra(SearchResultActivity.EXTRA_NAME);
        ArrayList<CharSequence> names = data.getCharSequenceArrayListExtra(SearchResultActivity.RESULT_SELECTED_NAMES);
        ArrayList<CharSequence> uris = data.getCharSequenceArrayListExtra(SearchResultActivity.RESULT_SELECTED_URIS);
        ArrayList<CharSequence> sizes = data.getCharSequenceArrayListExtra(SearchResultActivity.RESULT_SELECTED_SIZES);

        if (shareName == null || names == null || uris == null || sizes == null) {
            return;
        }

        ArrayList<ShareResource> shareResources = new ArrayList<>();
        for (int count=0; count<names.size(); count++) {
            ShareResource shareResource = new ShareResource();
            shareResource.setName(names.get(count).toString());
            shareResource.setLocation(uris.get(count).toString());
            shareResource.setSize(Long.parseLong(sizes.get(count).toString()));
            shareResources.add(shareResource);
        }

        /**
         * AddToPlaylistTask makes a Cloud SDK API call to add files to an existing playlist stored in the cloud.
         */
        CreateShareTask createShareTask = new CreateShareTask(this, this, cloudAPI, shareName, shareResources);
        createShareTask.execute();

        showProgressDialog(getString(R.string.loading));
    }
}
