/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.adapters;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.media.R;
import com.thingspace.media.cache.ImageCache;
import com.thingspace.media.cache.ImageFetcher;

/**
 * GridCursorAdapter to inflate grid items
 */
public class GridCursorAdapter extends BaseAdapter {

    private static ImageFetcher staticImageFetcher;

    protected Context context;
    protected int layoutID;
    protected ItemList itemList;
    protected int count;
    protected CloudAPI cloudAPI;

    /**
     * Inflate grid items and retrieve content tokens from SQLite to display thumbnails.
     *
     * @param context  context to initiate SimpleCursorAdapter and invoke inflater.
     * @param layout   resource identifier of a layout file that defines the views for this list item. The layout file should include at least those named views defined in "to"
     * @param cloudAPI Thingspace access token
     */
    public GridCursorAdapter(Context context, int layout, ItemList itemList, CloudAPI cloudAPI, int count) {
        this.context = context;
        this.layoutID = layout;
        this.cloudAPI = cloudAPI;
        this.itemList = itemList;
        this.count = count;
    }

    public GridCursorAdapter(Context context, int layout, ItemList itemList, CloudAPI cloudAPI) {
        this(context, layout, itemList, cloudAPI, itemList.getCount());
    }

    public ImageFetcher getImageFetcher() {
        if (staticImageFetcher == null) {
            ImageCache.ImageCacheParams cacheParams = new ImageCache.ImageCacheParams(context, "thumbs");
            cacheParams.setMemCacheSizePercent(context, 0.5f);

            staticImageFetcher = new ImageFetcher(context, context.getResources().getDimensionPixelSize(R.dimen.photo_item_size));
            staticImageFetcher.addImageCache(cacheParams);
        }
        return staticImageFetcher;
    }

    @Override
    public int getCount() {
        return count;
    }

    @Override
    public Object getItem(int position) {
        return position;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View view = LayoutInflater.from(context).inflate(layoutID, parent, false);
        final ViewHolder viewHolder = new ViewHolder((ImageView) view.findViewById(R.id.image));
        FullviewItem fullviewItem = (FullviewItem) itemList.getItem(position);
        if (fullviewItem == null) {
            return view;
        }
        String mimeType = fullviewItem.getMimeType();
        if (mimeType.indexOf("audio") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.music_icon);
        } else if (mimeType.indexOf("video") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.videos_icon);
        } else if (mimeType.indexOf("image") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.thumb_placeholder);
        } else if (mimeType.indexOf("directory") != -1) {
            getImageFetcher().setLoadingImage(R.drawable.folder_icon);
        } else {
            getImageFetcher().setLoadingImage(R.drawable.file_icon);
        }

        getImageFetcher().loadImage(fullviewItem.getContentToken(), viewHolder.imageView, cloudAPI);


        return view;
    }

    final class ViewHolder {
        ImageView imageView;

        public ViewHolder(ImageView imageView) {
            this.imageView = imageView;
        }
    }
}
