/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.dialog;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.media.R;
import com.thingspace.media.activities.SearchResultActivity;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * This class is used to display a dialog box to enter a share name.
 * Clicking "Create" button calls CreateShareTask which calls createShare api method call from CloudAPI.
 */
public class CreateShareDialog extends DialogFragment {

    private EditText editTextShareName;

    public Dialog onCreateDialog(Bundle savedInstanceState) {
        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());
        final LayoutInflater inflater = getActivity().getLayoutInflater();

        View dialogView = inflater.inflate(R.layout.dialog_create_share, null);
        builder.setView(dialogView);

        builder.setPositiveButton(R.string.create,
                new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        Intent intent = new Intent(getActivity(), SearchResultActivity.class);
                        intent.putExtra(SearchResultActivity.EXTRA_QUERY, CloudAPI.Search.MIME_TYPE + " LIKE '%image%'");
                        intent.putExtra(SearchResultActivity.EXTRA_LIMIT, 100);
                        intent.putExtra(SearchResultActivity.EXTRA_VIEW_MODE, SearchResultActivity.VIEW_MODE_SELECTION);
                        intent.putExtra(SearchResultActivity.EXTRA_TITLE, "Share Resources");
                        intent.putExtra(SearchResultActivity.EXTRA_NAME, editTextShareName.getText().toString());
                        startActivityForResult(intent, HubbleMediaTask.TASK_CREATE_SHARE);
                    }
                });

        builder.setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int id) {
                CreateShareDialog.this.getDialog().cancel();
            }
        });

        editTextShareName = (EditText) dialogView.findViewById(R.id.new_share_name);

        AlertDialog dialog = builder.create();
        dialog.setTitle(getString(R.string.create_share));
        dialog.show();
        return dialog;
    }
}
