/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.fragments;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.widget.GridLayoutManager;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.TextView;
import android.widget.Toast;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.callback.SearchCallback;
import com.thingspace.cloud.sdk.exception.SearchException;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.media.R;
import com.thingspace.media.activities.BaseActivity;
import com.thingspace.media.activities.PhotoActivity;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewGridAdapter;
import com.thingspace.media.listeners.RecyclerViewClickListener;
import com.thingspace.media.listeners.SortOptionChangeListener;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.DownloadTask;
import com.thingspace.media.views.SpaceItemDecorator;

/**
 * Base class for all the fragments used in this sample app.
 */
public class BaseFragment extends Fragment implements ThingspaceResponseListener, SortOptionChangeListener, AdapterView.OnItemClickListener, RecyclerViewClickListener, OnBindViewInterface {

    protected static final int LAYOUT_TYPE_LIST = 11;
    protected static final int LAYOUT_TYPE_GRID = 12;

    protected static final int ACTION_DOWNLOAD = 0;
    private static final int COLUMN_COUNT = 3;
    protected CloudAPI cloudAPI;
    protected RecyclerView recyclerView;
    protected ItemList itemList;
    protected TextView emptyView;
    private ProgressDialog progressDialog;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        /*
         * Initialize Cloud SDK API object using the Application Key, Secret and Callback URL that can be obtained from Key Management tab in ThingSpace portal.
         * Application Key, Secret and Callback URL needs to be updated in the build.gradle file.
         */
        cloudAPI = new CloudAPI(getString(R.string.APP_ID), getString(R.string.APP_SECRET), getString(R.string.CALLBACK_URL));
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.resource_recycler_view, container, false);
        recyclerView = (RecyclerView) view.findViewById(R.id.recyclerView);
        emptyView = ((TextView) view.findViewById(R.id.emptyView));

        switch (getLayoutType()) {
            case LAYOUT_TYPE_GRID:
                GridLayoutManager manager = new GridLayoutManager(getActivity(), COLUMN_COUNT);
                manager.setSpanSizeLookup(new GridLayoutManager.SpanSizeLookup() {
                    @Override
                    public int getSpanSize(int position) {
                        // for thumbs
                        return 1;
                    }
                });

                recyclerView.setLayoutManager(manager);
                recyclerView.setHasFixedSize(true);
                recyclerView.addItemDecoration(new SpaceItemDecorator(getResources().getDimensionPixelSize(R.dimen.thumb_spacing), 3));
                break;
            case LAYOUT_TYPE_LIST:
                recyclerView.setLayoutManager(new LinearLayoutManager(getActivity()));

        }

        executeQuery();
        return view;
    }

    @Override
    public void onResume() {
        super.onResume();
        ((BaseActivity) getActivity()).registerSortOptionChangeListener(this);
    }

    @Override
    public void onDetach() {
        super.onDetach();
        ((BaseActivity) getActivity()).unRegisterSortOptionChangeListener(this);
        if (itemList != null) {
            itemList.close();
        }
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (getActivity() instanceof ThingspaceResponseListener) {
            ((ThingspaceResponseListener) getActivity()).onResponse(taskCode, errorCode, response);
        }
    }

    @Override
    public void onSortOptionChange() {
        executeQuery();
    }

    protected String getQuery() {
        return null;
    }

    protected String getSortBy() {
        return null;
    }

    protected String getGroupBy() {
        return null;
    }

    protected int getLayoutType() {
        return LAYOUT_TYPE_GRID;
    }

    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        Toast.makeText(getActivity(), "Not supported yet", Toast.LENGTH_SHORT).show();
    }

    protected RecyclerView.Adapter getRecyclerViewAdapter(ItemList itemList) {
        return new RecyclerViewGridAdapter(getActivity(), R.layout.grid_item, itemList, cloudAPI, this, this);
    }

    public void executeQuery() {
        cloudAPI.search(getActivity(), CloudAPI.QueryType.SQL, getQuery(), getGroupBy(), getSortBy(), -1, new SearchCallback() {

            @Override
            public void onError(SearchException exception) {
                Log.e("SEARCH RESULTS --->", "Search error: " + exception);
            }

            @Override
            public void onSuccess(final ItemList itemList, final boolean isOffline) {
                getActivity().runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Log.e("SEARCH RESULTS --->", "search count: " + itemList.getCount() + " Offline: " + isOffline);
                        BaseFragment.this.itemList = itemList;
                        recyclerView.setAdapter(getRecyclerViewAdapter(itemList));
                    }
                });
            }
        });
    }

    @Override
    public void onListItemClicked(View view, int position) {
        Item item = itemList.getItem(position);
        String mimeType = null;

        if (item instanceof FullviewItem) {
            mimeType = ((FullviewItem) item).getMimeType();
        } else if (item instanceof File) {
            mimeType = ((File) item).getMimeType();
        }

        if (mimeType.indexOf("image") != -1) {
            Intent intent = new Intent(getActivity(), PhotoActivity.class);
            intent.putExtra(PhotoActivity.EXTRA_ITEM_NUMBER, position);
            PhotoActivity.setItemList(itemList);
            startActivity(intent);
        }
    }

    @Override
    public void onListItemLongClicked(View view, int position) {
        Item item = itemList.getItem(position);
        final String parentPath, name;

        if (item instanceof FullviewItem) {
            parentPath = ((FullviewItem) item).getParentPath();
            name = ((FullviewItem) item).getName();
        } else if (item instanceof File) {
            parentPath = ((File) item).getParentPath();
            name = ((File) item).getName();
        } else {
            return;
        }


        AlertDialog.Builder fileOperationDialog = new AlertDialog.Builder(getActivity());
        final ArrayAdapter<String> arrayAdapter = new ArrayAdapter<>(getActivity(), R.layout.list_item);

        arrayAdapter.add(getString(R.string.action_download));

        fileOperationDialog.setAdapter(arrayAdapter, new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                switch (which) {
                    case ACTION_DOWNLOAD:
                        DownloadTask downloadTask = new DownloadTask(getActivity(), BaseFragment.this, parentPath, name, cloudAPI);
                        downloadTask.execute();
                }
            }
        });

        fileOperationDialog.setTitle(getString(R.string.file_actions));
        fileOperationDialog.create();
        fileOperationDialog.show();
    }

    protected void showProgressDialog(String text) {
        progressDialog = ProgressDialog.show(getActivity(), "", text, true);
        progressDialog.setCancelable(true);
    }

    protected void dismissProgressDialog() {
        progressDialog.dismiss();
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
    }
}
