/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.fragments;

import android.content.Intent;
import android.support.v7.widget.RecyclerView;
import android.view.View;

import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Album;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.media.R;
import com.thingspace.media.activities.AlbumsFilesActivity;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewListAdapter;
import com.thingspace.media.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.media.cache.SortPreference;
import com.thingspace.media.tasks.HubbleMediaTask;
import com.thingspace.media.tasks.RetrieveMusicAlbumsTask;

/**
 * MusicAlbumsListFragment is called when "Albums" Tab is selected in Music which displays all the music albums stored in the cloud.
 * This Fragment calls RetrieveMusicAlbumsTask which in turn makes a Cloud SDK API call to retrieve all Music Albums stored under user's cloud storage.
 * When any Album is selected, it calls AlbumsFilesActivity to display the contents/Files in the album.
 */
public class MusicAlbumsListFragment extends BaseFragment implements OnBindViewInterface {//implements LoaderManager.LoaderCallbacks<Cursor> {

    public void executeQuery() {
        SortType sortType = SortType.ALBUM.setOrder(SortType.SortOrder.ASC);
        if (SortPreference.getSortPreference(getActivity()).equalsIgnoreCase(getActivity().getString(R.string.sort_date))) {
            sortType = SortType.CREATION_DATE.setOrder(SortType.SortOrder.ASC);
        }
        /**
         * RetrieveMusicAlbumsTask makes a Cloud SDK API call to retrieve all Music Albums stored under user's cloud storage.
         */
        RetrieveMusicAlbumsTask retrieveMusicAlbumsTask = new RetrieveMusicAlbumsTask(getActivity(), this, cloudAPI, sortType);
        retrieveMusicAlbumsTask.execute();
    }

    protected int getLayoutType() {
        return LAYOUT_TYPE_LIST;
    }

    protected RecyclerView.Adapter getRecyclerViewAdapter(ItemList itemList) {
        return new RecyclerViewListAdapter(R.layout.list_item, itemList, this, this);
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
        ((RecyclerViewListHolder) holder).textView.setText(((Album) item).getName());
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_MUSIC_ALBUMS) {
            if (response == null || !(response instanceof ItemList)) {
                return;
            }

            itemList = (ItemList<Album>) response;
            recyclerView.setAdapter(getRecyclerViewAdapter(itemList));
            return;
        }

        super.onResponse(taskCode, errorCode, response);
    }

    /**
     * When an album is selected, it calls AlbumsFilesActivity along with Source Type which displays Contents/Files of the album selected.
     */
    @Override
    public void onListItemClicked(View view, int position) {
        Album album = (Album) itemList.getItem(position);
        AlbumsFilesActivity.setAlbum(album);
        Intent intent = new Intent(getActivity(), AlbumsFilesActivity.class);
        intent.putExtra(AlbumsFilesActivity.EXTRA_NAME, album.getName());
        intent.putExtra(AlbumsFilesActivity.EXTRA_SOURCE_TYPE, AlbumsFilesActivity.TYPE_ALBUM);
        intent.putExtra(AlbumsFilesActivity.EXTRA_CONTENT_TYPE, AlbumsFilesActivity.CONTENT_TYPE_MUSIC);
        startActivity(intent);
    }
}
