/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.fragments;

import android.content.Intent;
import android.support.v7.widget.RecyclerView;
import android.view.View;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Genre;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.media.R;
import com.thingspace.media.activities.ArtistGenreFilesActivity;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewListAdapter;
import com.thingspace.media.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.media.tasks.HubbleMediaTask;
import com.thingspace.media.tasks.RetrieveMusicGenresTask;

/**
 * MusicGenreListFragment is called from MusicResourceTabActivity when "Genres" Tab is selected in Music which retrieves and displays all Genres stored in the cloud.
 * When genre name is clicked, it calls ArtistGenreFilesActivity which displays contents/files of the genre selected.
 */
public class MusicGenreListFragment extends BaseFragment implements OnBindViewInterface {

    public void executeQuery() {
        /**
         * RetrieveMusicGenresTask makes a Cloud SDK API call to retrieve all Music genres stored under user's cloud storage account.
         */
        RetrieveMusicGenresTask retrieveMusicGenresTask = new RetrieveMusicGenresTask(getActivity(), this, cloudAPI);
        retrieveMusicGenresTask.execute();
    }

    protected int getLayoutType() {
        return LAYOUT_TYPE_LIST;
    }

    protected RecyclerView.Adapter getRecyclerViewAdapter(ItemList itemList) {
        return new RecyclerViewListAdapter(R.layout.list_item, itemList, this, this);
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
        ((RecyclerViewListHolder) holder).textView.setText(((Genre) item).getName());
    }

    @Override
    public void onResponse(int taskCode, int errorCode, Object response) {
        if (taskCode == HubbleMediaTask.TASK_MUSIC_GENRE) {
            if (response == null || !(response instanceof ItemList)) {
                return;
            }

            itemList = (ItemList<Genre>) response;
            recyclerView.setAdapter(getRecyclerViewAdapter(itemList));
            return;
        }

        super.onResponse(taskCode, errorCode, response);
    }

    /**
     * When genre name is clicked, ArtistGenreFilesActivity is called which displays the files of that genre.
     * @param view
     * @param position
     */
    @Override
    public void onListItemClicked(View view, int position) {
        ArtistGenreFilesActivity.setGenre((Genre) itemList.getItem(position));
        Intent intent = new Intent(getActivity(), ArtistGenreFilesActivity.class);
        intent.putExtra(ArtistGenreFilesActivity.EXTRA_CONTENT_TYPE, ArtistGenreFilesActivity.CONTENT_TYPE_GENRE);
        startActivity(intent);
    }
}
