/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.app.Activity;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.media.listeners.ThingspaceResponseListener;

/**
 * Class to demonstrate Cloud SDK get account information api call.
 */
public class GetAccountInfoTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;

    /**
     * Retrieves the account information.
     *
     * @param activity                   Context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} class object to access user's cloud storage account
     */
    public GetAccountInfoTask(Activity activity, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI) {
        super(activity, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
    }

    @Override
    protected int getTaskCode() {
        return TASK_ACCOUNT_INFO;
    }


    @Override
    protected Object executeAPIRequest(String... params) {
        if (contextWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        /**
         * Cloud SDK api call to retrieve account memory information.
         */
        return cloudAPI.getAccountInformation(contextWeakReference.get());
    }
}
