/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.item.Audio;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.cloud.sdk.list.item.Photo;
import com.thingspace.cloud.sdk.list.item.Video;
import com.thingspace.media.listeners.ThingspaceResponseListener;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate Cloud SDK api call to get a file
 */
public class GetFileTask extends HubbleMediaTask {

    private final WeakReference<ImageView> imageViewWeakReference;
    protected String fileName;
    private WeakReference<Context> contextWeakReference;
    private String parentPath;
    private ProgressBar progressBar;
    private CloudAPI cloudAPI;

    /**
     * Get full file from the cloud.
     *
     * @param context                    Context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param parentPath                 Path to the directory where the file is stored under user's cloud storage account. Can be obtained using {@link FullviewItem}, {@link Photo}, {@link Video} or {@link Audio} classes.
     * @param fileName                   Name of the file to be downloaded from the cloud. Can be obtained using {@link FullviewItem}, {@link Photo}, {@link Video} or {@link Audio} classes.
     * @param cloudAPI                   CloudAPI object to access cloud api
     * @param imageView                  image view to bind the bitmap
     * @param progressBar                ProgressBar object to display/hide the progress
     */
    public GetFileTask(Context context, ThingspaceResponseListener thingspaceResponseListener, String parentPath, String fileName, CloudAPI cloudAPI, ImageView imageView, ProgressBar progressBar) {
        super(context, thingspaceResponseListener);
        this.parentPath = parentPath;
        this.fileName = fileName;
        imageViewWeakReference = new WeakReference<>(imageView);
        this.progressBar = progressBar;
        this.cloudAPI = cloudAPI;
        this.contextWeakReference = new WeakReference<>(context);
    }

    @Override
    protected Object executeAPIRequest(String... params) {
        if (contextWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = 2;
        if (isCancelled()) {
            return null;
        }

        /**
         * Cloud SDK api call to retrieve a file.
         */
        return BitmapFactory.decodeStream(cloudAPI.downloadFile(contextWeakReference.get(), parentPath, fileName), null, options);
    }

    @Override
    protected int getTaskCode() {
        return TASK_GET_FILE;
    }

    @Override
    protected void onPostExecute(Object response) {
        super.onPostExecute(response);
        progressBar.setVisibility(View.GONE);
        if (response == null) {
            return;
        }

        Bitmap bitmap = (Bitmap) response;
        if (imageViewWeakReference != null) {
            ImageView imageView = imageViewWeakReference.get();
            if (imageView != null) {
                imageView.setImageBitmap(bitmap);
            }
        } else {
            Log.e(getClass().getSimpleName(), "imageview weak reference null");
        }
    }
}
