/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.media.listeners.ThingspaceResponseListener;

import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Parent Async task for all Cloud SDK tasks.
 */
public abstract class HubbleMediaTask extends AsyncTask<String, Void, Object> {

    public static final int TASK_FULLVIEW = 101;
    public static final int TASK_DELTA = 102;
    public static final int TASK_ACCOUNT_INFO = 103;
    public static final int TASK_GET_FILE = 104;
    public static final int TASK_PLAYLIST = 105;
    public static final int TASK_UPLOAD = 106;
    public static final int TASK_DOWNLOAD = 107;
    public static final int TASK_CONTACTS = 108;
    public static final int TASK_PLAYLIST_ITEMS = 109;
    public static final int TASK_CREATE_PLAYLIST = 110;
    public static final int TASK_ADD_TO_PLAYLIST = 111;
    public static final int TASK_DELETE_PLAYLIST = 112;
    public static final int TASK_DELETE_PLAYLIST_ITEM = 113;
    public static final int TASK_UPDATE_PLAYLIST = 114;
    public static final int TASK_UPDATE_PLAYLIST_DEFINITION = 115;
    public static final int TASK_GET_PHOTOS = 116;
    public static final int TASK_GET_VIDEOS = 117;
    public static final int TASK_GET_AUDIOS = 118;
    public static final int TASK_GET_DOCUMENTS = 119;
    public static final int TASK_GET_PHOTO_ALBUMS = 120;
    public static final int TASK_AUDIO_PLAYLIST = 121;
    public static final int TASK_MUSIC_ALBUMS = 122;
    public static final int TASK_ALBUM_FILES = 123;
    public static final int TASK_MUSIC_GENRE = 124;
    public static final int TASK_MUSIC_ARTIST = 125;
    public static final int TASK_ARTIST_FILES = 126;
    public static final int TASK_GENRE_FILES = 127;
    public static final int TASK_PLAYLIST_FILES = 128;
    public static final int TASK_GET_SHARES = 129;
    public static final int TASK_DELETE_SHARE = 130;
    public static final int TASK_CREATE_SHARE = 131;

    protected WeakReference<Context> contextWeakReference;
    protected WeakReference<ThingspaceResponseListener> responseListenerWeakReference;
    protected int responseCode;

    /**
     * Parent class to access Cloud SDK
     *
     * @param context          Context object
     * @param responseListener Response listener to receive cloud api response
     */
    public HubbleMediaTask(Context context, ThingspaceResponseListener responseListener) {
        this.contextWeakReference = new WeakReference<>(context);
        this.responseListenerWeakReference = new WeakReference<>(responseListener);
    }

    protected Object doInBackground(String... params) {
        try {
            /**
             * Method to be overridden by all sub classes accessing Cloud SDK apis.
             */
            return executeAPIRequest(params);
        } catch (IllegalArgumentException e) {
            Log.d(this.getClass().getSimpleName(), "Illegal Argument Exception accessing API: " + e);
        } catch (CloudAPIException cloudAPIException) {
            Log.e(getClass().getSimpleName(), "CloudAPIException: " + cloudAPIException.getMessage());
            if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                /**
                 * return error code Unauthorized to be handled by view to begin authorization process.
                 */
                responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
                return HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }

            return onCloudAPIException(cloudAPIException);
        }
        return null;
    }

    protected Object onCloudAPIException(CloudAPIException ex) {
        return null;
    }

    protected abstract Object executeAPIRequest(String... params);

    protected abstract int getTaskCode();

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(Object response) {
        super.onPostExecute(response);

        if (responseListenerWeakReference.get() == null) {
            Log.e(getClass().getSimpleName(), "response listener reference null");
            return;
        }

        responseListenerWeakReference.get().onResponse(getTaskCode(), responseCode, response);
    }
}
