/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.item.Playlist;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

import java.util.ArrayList;

/**
 * Class to demonstrate API call to add files to an existing playlist.
 */
public class AddToPlaylistTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String uid;
    private ArrayList<String> paths;

    /**
     * Add files to an existing playlist stored in the cloud.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param uid                        Unique identifier of an existing playlist as obtained from {@link Playlist#getUid()}
     * @param paths                      An array list of all the file paths to be added to the playlist.
     */
    public AddToPlaylistTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String uid, ArrayList<String> paths) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.uid = uid;
        this.paths = paths;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK method call to add files to an existing playlist
         */
        return cloudAPI.addToPlaylist(contextWeakReference.get(), uid, paths);
    }

    @Override
    protected int getTaskCode() {
        return TASK_ADD_TO_PLAYLIST;
    }
}
