/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.PlaylistType;
import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK API call to retrieve all playlists stored under user's cloud storage account
 */
public class RetrievePlaylistsTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private PlaylistType playlistType;
    private SortType sortType;

    /**
     * Retrieve all playlists stored under user's cloud storage account
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param playlistType               Type of the playlist as defined in {@link PlaylistType}
     * @param sortType                   sort order for the response list
     */
    public RetrievePlaylistsTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, PlaylistType playlistType, SortType sortType) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.playlistType = playlistType;
        this.sortType = sortType;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve all playlists from the cloud.
         */
        return cloudAPI.getPlaylists(contextWeakReference.get(), playlistType, sortType, -1, -1);
    }

    @Override
    protected int getTaskCode() {
        return TASK_PLAYLIST;
    }
}
