/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.PlaylistType;
import com.thingspace.cloud.sdk.list.item.Playlist;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

import java.util.ArrayList;

/**
 * Class to demonstrate Cloud SDK API call to update an existing Playlist by updating its definition and replacing the files in the old playlist.
 */
public class UpdatePlaylistDefinitionTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private PlaylistType playlistType;
    private String name, uid;
    private ArrayList<String> paths;

    /**
     * Update a playlist definition - This call replaces the existing playlist definition, by updating its definition and replacing the files linked with this playlist.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param uid                        Playlist uid as obatained from {@link Playlist#getUid()}
     * @param name                       New name of the playlist
     * @param paths                      Paths of files to be included in the new playlist definition.
     * @param playlistType               Playlist type as defined in {@link PlaylistType}
     */
    public UpdatePlaylistDefinitionTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String uid, String name, ArrayList<String> paths, PlaylistType playlistType) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.playlistType = playlistType;
        this.name = name;
        this.paths = paths;
        this.uid = uid;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to update an existing playlist definition.
         */
        return cloudAPI.updatePlaylistDefinition(contextWeakReference.get(), uid, name, playlistType, paths);
    }

    @Override
    protected int getTaskCode() {
        return TASK_UPDATE_PLAYLIST_DEFINITION;
    }
}
